#!/usr/bin/env python

import csv
import sys
import numpy as np

f0 = sys.argv[1]
f1 = sys.argv[2]
f2 = sys.argv[3]

data0 = csv.reader(open(f0, 'r'))
data1 = csv.reader(open(f1, 'r'))
data2 = csv.reader(open(f2, 'r'))

# advance past header
header = data0.next()
data1.next()
data2.next()

# print new header
header.append('stderr')
print ','.join(header)

# parse rows averaging and generating standard error for total
for x0, x1, x2 in zip(*[data0,data1,data2]):
  row = []
  for i, (v0, v1, v2) in enumerate(zip(x0, x1, x2)):
    if header[i] in ['kernel', 'status']:
      if not v0 == v1 == v2:
        print 'Error: mismatch in kernel or status', v0, v1, v2
        sys.exit(1)
      row.append(v0)
    else:
      ts = [ float(x) for x in [v0,v1,v2] ]
      mean = np.mean(ts)
      std = np.std(ts, ddof=1) #< sample standard deviation
      sem = std / np.sqrt(3)   #< standard error of mean
      err = 3.182 * sem        #< 95 standard error assuming 2-tail t-distribution
      if header[i] == 'total':
        row.extend([ '%.3f' % x for x in [mean, err]])
      else:
        row.append('%.3f' % mean)
  print ','.join(row)
